Index: sansmodels/src/sans/models/c_extensions/DiamCyl.c
===================================================================
--- sansmodels/src/sans/models/c_extensions/DiamCyl.c	(revision cabe74bf343c045ec7fcc1de8a7fdc9065ccb5cb)
+++ sansmodels/src/sans/models/c_extensions/DiamCyl.c	(revision 5eb91544a3ee42b368ccec3ebcf8e95f75b020a2)
@@ -16,9 +16,10 @@
  */
 double DiamCyld_analytical_1D(DiamCyldParameters *pars, double q) {
-	double dp[2];
+	double cylh;
+	double cylr;
 
-	dp[0] = pars->radius;
-	dp[1] = pars->length;
-	return DiamCyl(dp, q);
+	cylr = pars->radius;
+	cylh = pars->length;
+	return DiamCyl(cylh, cylr);
 }
 
Index: sansmodels/src/sans/models/c_extensions/DiamEllip.c
===================================================================
--- sansmodels/src/sans/models/c_extensions/DiamEllip.c	(revision cabe74bf343c045ec7fcc1de8a7fdc9065ccb5cb)
+++ sansmodels/src/sans/models/c_extensions/DiamEllip.c	(revision 5eb91544a3ee42b368ccec3ebcf8e95f75b020a2)
@@ -16,9 +16,9 @@
  */
 double DiamEllips_analytical_1D(DiamEllipsParameters *pars, double q) {
-	double dp[2];
+	double ell_a, ell_b;
 
-	dp[0] = pars->radius_a;
-	dp[1] = pars->radius_b;
-	return DiamEllip(dp, q);
+	ell_a = pars->radius_a;
+	ell_b = pars->radius_b;
+	return DiamEllip(ell_a, ell_b);
 }
 
Index: sansmodels/src/sans/models/c_extensions/Hardsphere.c
===================================================================
--- sansmodels/src/sans/models/c_extensions/Hardsphere.c	(revision 25579e8c451417db52ac6ed70a3c116d52d8717d)
+++ sansmodels/src/sans/models/c_extensions/Hardsphere.c	(revision 5eb91544a3ee42b368ccec3ebcf8e95f75b020a2)
@@ -11,5 +11,5 @@
 /**
  * Function to evaluate 1D scattering function
- * @param pars: parameters of the HardsphereStructure 
+ * @param pars: parameters of the HardsphereStructure
  * @param q: q-value
  * @return: function value
@@ -17,10 +17,12 @@
 double Hardsphere_analytical_1D(HardsphereParameters *pars, double q) {
 	double dp[2];
-	
-	dp[0] = pars->radius;
-	dp[1] = pars->volfraction;	
+	if (q == 0){
+		return 0.2;
+	}
+	dp[0] = pars->effect_radius;
+	dp[1] = pars->volfraction;
 	return HardSphereStruct(dp, q);
 }
-    
+
 /**
  * Function to evaluate 2D scattering function
@@ -34,4 +36,4 @@
 
 double Hardsphere_analytical_2DXY(HardsphereParameters *pars, double qx, double qy){
-	return Hardsphere_analytical_1D(pars,sqrt(qx*qx+qy*qy));	
+	return Hardsphere_analytical_1D(pars,sqrt(qx*qx+qy*qy));
 }
Index: sansmodels/src/sans/models/c_extensions/HayterMSA.c
===================================================================
--- sansmodels/src/sans/models/c_extensions/HayterMSA.c	(revision 25579e8c451417db52ac6ed70a3c116d52d8717d)
+++ sansmodels/src/sans/models/c_extensions/HayterMSA.c	(revision 5eb91544a3ee42b368ccec3ebcf8e95f75b020a2)
@@ -1,4 +1,4 @@
 /**
- * SquareWell Structure factor 
+ * SquareWell Structure factor
  * @author: Jae Hie Cho / UTK
  */
@@ -18,5 +18,5 @@
 	double dp[6];
 
-	dp[0] = pars->radius;
+	dp[0] = pars->effect_radius;
 	dp[1] = pars->charge;
 	dp[1] = pars->volfraction;
@@ -24,8 +24,8 @@
 	dp[4] = pars->saltconc;
 	dp[5] = pars->dielectconst;
-	
+
 	return HayterPenfoldMSA(dp, q);
 }
-    
+
 /**
  * Function to evaluate 2D scattering function
@@ -39,4 +39,4 @@
 
 double HayterMSA_analytical_2DXY(HayterMSAParameters *pars, double qx, double qy){
-	return HayterMSA_analytical_1D(pars,sqrt(qx*qx+qy*qy));	
+	return HayterMSA_analytical_1D(pars,sqrt(qx*qx+qy*qy));
 }
Index: sansmodels/src/sans/models/c_extensions/HayterMSA.h
===================================================================
--- sansmodels/src/sans/models/c_extensions/HayterMSA.h	(revision 1ed3834d2e968f8ff632d0b368f55ac28174df7a)
+++ sansmodels/src/sans/models/c_extensions/HayterMSA.h	(revision 5eb91544a3ee42b368ccec3ebcf8e95f75b020a2)
@@ -6,5 +6,5 @@
  */
  //[PYTHONCLASS] = HayterMSAStructure
- //[DISP_PARAMS] = radius
+ //[DISP_PARAMS] = effect_radius
  //[DESCRIPTION] =<text>To calculate the structure factor (the Fourier transform of the
  //                     pair correlation function g(r)) for a system of
@@ -22,10 +22,10 @@
  //
  //				</text>
- //[FIXED]= radius.width
+ //[FIXED]= effect_radius.width
 
 typedef struct {
-    ///	Radius of particle [A]
-    //  [DEFAULT]=radius=20.75 [A]
-    double radius;
+    ///	effetitve radius of particle [A]
+    //  [DEFAULT]=effect_radius=20.75 [A]
+    double effect_radius;
 
     /// charge
Index: sansmodels/src/sans/models/c_extensions/SquareWell.c
===================================================================
--- sansmodels/src/sans/models/c_extensions/SquareWell.c	(revision 25579e8c451417db52ac6ed70a3c116d52d8717d)
+++ sansmodels/src/sans/models/c_extensions/SquareWell.c	(revision 5eb91544a3ee42b368ccec3ebcf8e95f75b020a2)
@@ -1,4 +1,4 @@
 /**
- * SquareWell Structure factor 
+ * SquareWell Structure factor
  * @author: Jae Hie Cho / UTK
  */
@@ -20,12 +20,12 @@
 	double dp[4];
 
-	dp[0] = pars->radius;
+	dp[0] = pars->effect_radius;
 	dp[1] = pars->volfraction;
 	dp[2] = pars->welldepth;
 	dp[3] = pars->wellwidth;
-	
+
 	return SquareWellStruct(dp, q);
 }
-    
+
 /**
  * Function to evaluate 2D scattering function
@@ -39,4 +39,4 @@
 
 double SquareWell_analytical_2DXY(SquareWellParameters *pars, double qx, double qy){
-	return SquareWell_analytical_1D(pars,sqrt(qx*qx+qy*qy));	
+	return SquareWell_analytical_1D(pars,sqrt(qx*qx+qy*qy));
 }
Index: sansmodels/src/sans/models/c_extensions/SquareWell.h
===================================================================
--- sansmodels/src/sans/models/c_extensions/SquareWell.h	(revision 1ed3834d2e968f8ff632d0b368f55ac28174df7a)
+++ sansmodels/src/sans/models/c_extensions/SquareWell.h	(revision 5eb91544a3ee42b368ccec3ebcf8e95f75b020a2)
@@ -5,5 +5,5 @@
 */
 //   [PYTHONCLASS] = SquareWellStructure
-//   [DISP_PARAMS] = radius
+//   [DISP_PARAMS] = effect_radius
 //   [DESCRIPTION] = <text> Structure Factor for interacting particles:             .
 //
@@ -14,5 +14,5 @@
 //			= 0     , r >= 2Rw
 //
-//		R: radius (A)of the particle
+//		R: effective radius (A)of the particle
 //		v: volume fraction
 //		d: well depth
@@ -23,12 +23,12 @@
 //      K. C., Physica, 1977, 89A, 213.
 //   			</text>
-//   [FIXED]= radius.width
+//   [FIXED]= effect_radius.width
 //[ORIENTATION_PARAMS]= <text> </text>
 
 
 typedef struct {
-    ///	Radius of particle [A]
-    //  [DEFAULT]=radius=50.0 [A]
-    double radius;
+    ///	effective radius of particle [A]
+    //  [DEFAULT]=effect_radius=50.0 [A]
+    double effect_radius;
 
     /// Volume fraction
Index: sansmodels/src/sans/models/c_extensions/StickyHS.c
===================================================================
--- sansmodels/src/sans/models/c_extensions/StickyHS.c	(revision 25579e8c451417db52ac6ed70a3c116d52d8717d)
+++ sansmodels/src/sans/models/c_extensions/StickyHS.c	(revision 5eb91544a3ee42b368ccec3ebcf8e95f75b020a2)
@@ -17,12 +17,12 @@
 double StickyHS_analytical_1D(StickyHSParameters *pars, double q) {
 	double dp[4];
-	
-	dp[0] = pars->radius;
-	dp[1] = pars->volfraction;	
+
+	dp[0] = pars->effect_radius;
+	dp[1] = pars->volfraction;
 	dp[2] = pars->perturb;
-	dp[3] = pars->stickiness;	
+	dp[3] = pars->stickiness;
 	return StickyHS_Struct(dp, q);
 }
-    
+
 /**
  * Function to evaluate 2D scattering function
@@ -36,4 +36,4 @@
 
 double StickyHS_analytical_2DXY(StickyHSParameters *pars, double qx, double qy){
-	return StickyHS_analytical_1D(pars,sqrt(qx*qx+qy*qy));	
+	return StickyHS_analytical_1D(pars,sqrt(qx*qx+qy*qy));
 }
Index: sansmodels/src/sans/models/c_extensions/multishell.h
===================================================================
--- sansmodels/src/sans/models/c_extensions/multishell.h	(revision 2cc633bae7266a8ade40cec768899907446f505e)
+++ sansmodels/src/sans/models/c_extensions/multishell.h	(revision 5eb91544a3ee42b368ccec3ebcf8e95f75b020a2)
@@ -7,5 +7,5 @@
 	[PYTHONCLASS] = MultiShellModel
 	[DISP_PARAMS] = core_radius, s_thickness, w_thickness
-	[DESCRIPTION] =<text>Model parameters:
+	[DESCRIPTION] =<text> MultiShell (Sphere) Model (or Multilamellar Vesicles): Model parameters;
 				scale : scale factor
 				core_radius : Core radius of the multishell
Index: sansmodels/src/sans/models/c_extensions/spheroid.h
===================================================================
--- sansmodels/src/sans/models/c_extensions/spheroid.h	(revision eddff027b43bf6dfb5f35d7d30e3a458f64c1c41)
+++ sansmodels/src/sans/models/c_extensions/spheroid.h	(revision 5eb91544a3ee42b368ccec3ebcf8e95f75b020a2)
@@ -14,5 +14,5 @@
 			polar_core = polar radius of core,
 			equat_shell = equatorial radius of shell,
-			polar_shell = polar radius of shell,
+			polar_shell = polar radius (revolution axis) of shell,
 			contrast = SLD_core - SLD_shell
 			sld_solvent = SLD_solvent
@@ -21,6 +21,6 @@
 			Note:It is the users' responsibility to ensure
 			that shell radii are larger than core radii.
-			oblate shell: equatorial radius > polar radius
-			prolate shell: equatorial radius < polar radius
+			oblate: polar radius < equatorial radius
+			prolate :  polar radius > equatorial radius
 			</text>
 

Index: sansmodels/src/sans/models/c_extensions/Hardsphere.h
===================================================================
--- sansmodels/src/sans/models/c_extensions/Hardsphere.h	(revision 1ed3834d2e968f8ff632d0b368f55ac28174df7a)
+++ sansmodels/src/sans/models/c_extensions/Hardsphere.h	(revision 5eb91544a3ee42b368ccec3ebcf8e95f75b020a2)
@@ -6,5 +6,5 @@
  */
  //[PYTHONCLASS] = HardsphereStructure
- //[DISP_PARAMS] = radius
+ //[DISP_PARAMS] = effect_radius
  //[DESCRIPTION] =<text>Structure factor for interacting particles:                   .
  //
@@ -14,5 +14,5 @@
  //                         = 0     , r >= 2R
  //
- //						R: radius of the Hardsphere particle
+ //						R: effective radius of the Hardsphere particle
  //						V:The volume fraction
  //
@@ -20,11 +20,11 @@
  //     Rev. 1958, 110, 1.
  //	 </text>
- //[FIXED]= radius.width
+ //[FIXED]= effect_radius.width
 
 
 typedef struct {
-    /// Radius of hardsphere [A]
-    //  [DEFAULT]=radius=50.0 [A]
-    double radius;
+    /// effect radius of hardsphere [A]
+    //  [DEFAULT]=effect_radius=50.0 [A]
+    double effect_radius;
 
     ///	Volume fraction
Index: sansmodels/src/sans/models/c_extensions/StickyHS.h
===================================================================
--- sansmodels/src/sans/models/c_extensions/StickyHS.h	(revision 1ed3834d2e968f8ff632d0b368f55ac28174df7a)
+++ sansmodels/src/sans/models/c_extensions/StickyHS.h	(revision 5eb91544a3ee42b368ccec3ebcf8e95f75b020a2)
@@ -6,5 +6,5 @@
  */
  //[PYTHONCLASS] = StickyHSStructure
- //[DISP_PARAMS] = radius
+ //[DISP_PARAMS] = effect_radius
  //[DESCRIPTION] =<text> Structure Factor for interacting particles:                               .
  //
@@ -15,5 +15,5 @@
  //                         = 0   , r >= 2R +w
  //
- //						R: radius of the hardsphere
+ //						R: effective radius of the hardsphere
  //                     stickiness = [exp(Uo/kT)]/(12*perturb)
  //                     perturb = w/(w+ 2R) , 0.01 =< w <= 0.1
@@ -24,9 +24,9 @@
  //                      Phys., 1991, 95(12), 9186-9190.
  //				</text>
- //[FIXED]= radius.width
+ //[FIXED]= effect_radius.width
 typedef struct {
-    /// Radius of hardsphere [A]
-    //  [DEFAULT]=radius=50.0 [A]
-    double radius;
+    /// effect radius of hardsphere [A]
+    //  [DEFAULT]=effect_radius=50.0 [A]
+    double effect_radius;
 
     ///	Volume fraction